@@ -1,8 +1,11 @@
-#!/usr/bin/env ruby
+#!/usr/bin/ruby
 #
 # action.rb -- IKEGAMI Daisuke
 # original is http://ming.sourceforge.net/examples/example.php?name=action
 # $Log: action.rb,v $
+# Revision 1.2  2006/12/17 18:49:58  mcdonaec
+# New examples added.
+#
 # Revision 1.1  2004/10/31 13:52:10  ikegami
 # initial commit
 #
@@ -40,9 +43,9 @@ i.set_depth(1)
 i.move_to(-50, 120)
 i.set_name('box')
 
-m.add(SWFAction.new('box._x += 3;'))
+m.add(SWFAction.new("box._x += 3;"))
 m.next_frame
-m.add(SWFAction.new('prevFrame(); play();'))
+m.add(SWFAction.new("prevFrame(); play();"))
 m.next_frame
 
 m.save('action.swf')
