@@ -1,8 +1,11 @@
-#!/usr/bin/env ruby
+#!/usr/bin/ruby
 #
 # keypress.rb -- IKEGAMI Daisuke
 #
 # $Log: keypress.rb,v $
+# Revision 1.2  2006/12/17 18:49:59  mcdonaec
+# New examples added.
+#
 # Revision 1.1  2004/11/07 17:34:22  ikegami
 # NEWS: version 0.1.7 shipped.
 # some bugs are fixed, and it seems work with Ming 0.3beta1.
@@ -12,7 +15,7 @@ require 'ming/ming'
 include Ming
 
 p = SWFMovieClip.new
-p.add(SWFAction.new('stop();'))
+p.add(SWFAction.new("stop();"))
 
 chars = 'abcdefghijklmnopqrstuvwxyz' +
         'ABCDEFGHIJKLMNOPQRSTUVWXYZ' +
